@@ -5,12 +5,18 @@ This module provides a single interface to execute different types of agents
 using the existing BAMLService infrastructure.
 """
 
-from .executor import execute_agent, AgentResponse
-
-from .utils.project_context import get_project_context_for_agent
-
 # Re-export BAML types for convenience
-from baml_client.types import Agent, ProjectContext, RoadmapAgentParams, RoadmapResponse,RoadmapCompletionParams , BaseCompletionParams
+from baml_client.types import (
+    Agent,
+    BaseCompletionParams,
+    ProjectContext,
+    RoadmapAgentParams,
+    RoadmapCompletionParams,
+    RoadmapResponse,
+)
+
+from .executor import AgentResponse, execute_agent
+from .utils.project_context import get_project_context_for_agent
 
 __all__ = [
     # Agent execution functions
