@@ -2,9 +2,14 @@
 Graph module initialization.
 """
 
-from graph.sqlite_client import SQLiteConnection
-from graph.graph_operations import GraphOperations
 from graph.converter import ASTToSqliteConverter
+from graph.graph_operations import GraphOperations
 from graph.project_indexer import ProjectIndexer
+from graph.sqlite_client import SQLiteConnection
 
-__all__ = ["SQLiteConnection", "GraphOperations", "ASTToSqliteConverter", "ProjectIndexer"]
+__all__ = [
+    "SQLiteConnection",
+    "GraphOperations",
+    "ASTToSqliteConverter",
+    "ProjectIndexer",
+]
